#!/usr/bin/env python
from vtkmodules.vtkCommonExecutionModel import (
    vtkSimpleScalarTree,
    vtkSpanSpace,
)
from vtkmodules.vtkFiltersCore import (
    vtkContourFilter,
    vtkExecutionTimer,
)
from vtkmodules.vtkFiltersModeling import vtkOutlineFilter
from vtkmodules.vtkFiltersSMP import vtkSMPContourGrid
from vtkmodules.vtkIOExodus import vtkExodusIIReader
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkCompositePolyDataMapper,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Create the RenderWindow, Renderer
#
ren0 = vtkRenderer()
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.SetMultiSamples(0)
renWin.AddRenderer(ren0)
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

reader = vtkExodusIIReader()
reader.SetFileName(VTK_DATA_ROOT + "/Data/disk_out_ref.ex2")
reader.SetPointResultArrayStatus("Temp",1);
reader.Update ();
input = reader.GetOutput().GetBlock(0).GetBlock(0);

# Create scalar trees to test
sTree = vtkSimpleScalarTree()
sTree.SetBranchingFactor(3)

spanTree = vtkSpanSpace()
spanTree.SetResolution(100);

# First create the usual contour grid (non-threaded)
cf = vtkContourFilter()
cf.SetInputData(input)
cf.SetUseScalarTree(1)
cf.SetValue(0,350)
cf.SetInputArrayToProcess(0, 0, 0, 0, "Temp");
cf.GenerateTrianglesOff()

contourMapper = vtkPolyDataMapper()
contourMapper.SetInputConnection(cf.GetOutputPort())
contourMapper.ScalarVisibilityOff()

contourActor = vtkActor()
contourActor.SetMapper(contourMapper)
contourActor.GetProperty().SetColor(1,1,1)

outline = vtkOutlineFilter()
outline.SetInputData(input)

outlineMapper = vtkPolyDataMapper()
outlineMapper.SetInputConnection(outline.GetOutputPort())

outlineActor = vtkActor()
outlineActor.SetMapper(outlineMapper)

# Now create the threaded version. Note that as of the
# writing of this test, vtkSMPContourGrid does not merge
# pieces properly hence MergePieces is disabled. Also
# vtkSMPContourGrid only outputs triangles.
cfT = vtkSMPContourGrid()
cfT.SetInputData(input)
cfT.UseScalarTreeOn()
cfT.SetValue(0,350)
cfT.SetInputArrayToProcess(0, 0, 0, 0, "Temp");
cfT.GenerateTrianglesOff()
cfT.MergePiecesOff()

# Note: Since MergePieces is off, we have to use a
# vtkCompositePolyDataMapper.
contourMapperT = vtkCompositePolyDataMapper()
contourMapperT.SetInputConnection(cfT.GetOutputPort())
contourMapperT.ScalarVisibilityOff()

contourActorT = vtkActor()
contourActorT.SetMapper(contourMapperT)
contourActorT.GetProperty().SetColor(1,1,1)

outlineT = vtkOutlineFilter()
outlineT.SetInputData(input)

outlineMapperT = vtkPolyDataMapper()
outlineMapperT.SetInputConnection(outlineT.GetOutputPort())

outlineActorT = vtkActor()
outlineActorT.SetMapper(outlineMapperT)

# Time the execution of the filter w/out scalar tree
CG_timer = vtkExecutionTimer()
CG_timer.SetFilter(cf)
cf.UseScalarTreeOff()
cf.Update()
CG = CG_timer.GetElapsedWallClockTime()
print ("Contour Grid (no Scalar Tree):", CG)

# Time the execution of the filter w/ simple scalar tree
CG_timer0 = vtkExecutionTimer()
CG_timer0.SetFilter(cf)
cf.UseScalarTreeOn()
cf.SetScalarTree(sTree)
cf.Update()
CG0 = CG_timer0.GetElapsedWallClockTime()
print ("Contour Grid (build & execute Simple Scalar Tree):", CG0)

CG_timer1 = vtkExecutionTimer()
CG_timer1.SetFilter(cf)
cf.Modified()
cf.Update()
CG1 = CG_timer1.GetElapsedWallClockTime()
print ("Contour Grid (Simple Scalar Tree):", CG1)

# Time the execution of the filter
CG2_timer0 = vtkExecutionTimer()
CG2_timer0.SetFilter(cf)
cf.SetScalarTree(spanTree)
cf.Update()
CG2 = CG2_timer0.GetElapsedWallClockTime()
print ("Contour Grid (build & execute Span Tree):", CG2)

CG2_timer1 = vtkExecutionTimer()
CG2_timer1.SetFilter(cf)
cf.Modified()
cf.Update()
CG3 = CG2_timer1.GetElapsedWallClockTime()
print ("Contour Grid (Span Tree):", CG3)

# Okay now execute the threaded algorithms
# Time the execution of the filter w/out scalar tree
CG_timer.SetFilter(cfT)
cfT.UseScalarTreeOff()
cfT.Update()
CG = CG_timer.GetElapsedWallClockTime()
print ("SMPContour Grid (no Scalar Tree):", CG)

# Time the execution of the filter w/ simple scalar tree
CG_timer0.SetFilter(cfT)
cfT.UseScalarTreeOn()
cfT.SetScalarTree(sTree)
cfT.Update()
CG0 = CG_timer0.GetElapsedWallClockTime()
print ("SMPContour Grid (build & execute Simple Scalar Tree):", CG0)

CG_timer1 = vtkExecutionTimer()
CG_timer1.SetFilter(cfT)
cfT.Modified()
cf.Update()
CG1 = CG_timer1.GetElapsedWallClockTime()
print ("SMPContour Grid (Simple Scalar Tree):", CG1)

# Time the execution of the filter
CG2_timer0 = vtkExecutionTimer()
CG2_timer0.SetFilter(cfT)
cfT.SetScalarTree(spanTree)
cfT.Update()
CG2 = CG2_timer0.GetElapsedWallClockTime()
print ("SMPContour Grid (build & execute Span Tree):", CG2)

CG2_timer1 = vtkExecutionTimer()
CG2_timer1.SetFilter(cfT)
cfT.Modified()
cfT.Update()
CG3 = CG2_timer1.GetElapsedWallClockTime()
print ("SMPContour Grid (Span Tree):", CG3)

# Add the actors to the renderer, set the background and size
#
ren0.AddActor(outlineActor)
ren0.AddActor(contourActor)
ren1.AddActor(outlineActorT)
ren1.AddActor(contourActorT)

ren0.SetBackground(0,0,0)
ren1.SetBackground(0,0,0)
ren0.SetViewport(0,0,0.5,1);
ren1.SetViewport(0.5,0,1,1);
renWin.SetSize(600,300)
ren0.ResetCamera()
ren1.ResetCamera()
iren.Initialize()

renWin.Render()
#iren.Start()
# --- end of script --



# SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
# SPDX-License-Identifier: BSD-3-Clause
from vtkmodules.vtkCommonCore import vtkStringToken
from vtkmodules.vtkCommonDataModel import vtkCellGrid
from vtkmodules.vtkCommonExecutionModel import vtkStreamingDemandDrivenPipeline
from vtkmodules.vtkFiltersSources import vtkCubeSource, vtkOutlineCornerFilter
from vtkmodules.vtkFiltersCellGrid import vtkCellGridComputeSides
from vtkmodules.vtkRenderingCore import vtkRenderWindow, vtkRenderer, vtkActor, vtkPolyDataMapper
from vtkmodules.vtkRenderingOpenGL2 import vtkArrayRenderer, vtkShader, vtkShaderProgram
from vtkmodules.vtkInteractionWidgets import vtkCameraOrientationWidget
from vtkmodules.vtkIOCellGrid import vtkCellGridReader
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

from vtkmodules.test import Testing

# Add the directory containing this file to the python path
# so we can import the shader source from the subdirectory:
import os
import sys
sys.path.append(os.path.dirname(__file__))
from shaders import vertShaderSource, fragShaderSource

filename = os.path.join(VTK_DATA_ROOT, 'Data', 'dgTetrahedra.dg')
cellAttName = None
cellAttType = None
interact = '-I' in sys.argv
if len(sys.argv) > 1:
    if sys.argv[1] != '-D':
        interact = True # Always run interactively if no data directory.
        # When run manually, accept a filename, an attribute name (for
        # coloring), and an attribute type.
        filename = sys.argv[1]
        print('Read', filename)
        if len(sys.argv) > 2:
            cellAttName = vtkStringToken(sys.argv[2])
            print('Color by', cellAttName.Data())
        else:
            cellAttName = None
        if len(sys.argv) > 3:
            cellAttType = vtkStringToken(sys.argv[3])
        else:
            cellAttType = None

# Create objects for a scene.
rw = vtkRenderWindow()
ri = rw.MakeRenderWindowInteractor()
rr = vtkRenderer()
ac = vtkActor()
ar = vtkArrayRenderer()
cr = vtkCellGridReader()
cs = vtkCellGridComputeSides()
ow = vtkCameraOrientationWidget()

# Configure the pipeline
rw.AddRenderer(rr)
rr.AddActor(ac)
cr.SetFileName(filename)
cs.SetInputConnection(cr.GetOutputPort())
cs.Update()
# Grab the cell-grid object representing the surface to render.
# We'll use arrays from the cell-grid to define the rendering.
cg = cs.GetOutputDataObject(0)
if cellAttName == None:
    cellAttName = vtkStringToken('scalar2')
if cellAttType == None:
    cellAttType = vtkStringToken('DG HGRAD C1')
bds = [0., 0., 0., 0., 0., 0.]
cg.GetBounds(bds)
print('Bounds are ', bds)
cg.GetUnorderedCellAttributeIds()
for cellTypeName in cg.GetCellTypes():
    print('  %s' % cellTypeName)
ac.SetMapper(ar)
ar.SetInputDataObject(0, cg)
ar.SetNumberOfElements(1)
ar.SetElementType(vtkArrayRenderer.Triangle)
ar.SetVertexShaderSource(vertShaderSource)
ar.SetFragmentShaderSource(fragShaderSource)

# Bind some arrays from the dataset.

# 0. Bind tetrahedron-specific metadata texture
side_offsets = cg.GetCellType('vtkDGTet').GetSideOffsetsAndShapes()
ar.BindArrayToTexture('side_offsets', side_offsets)
side_local = cg.GetCellType('vtkDGTet').GetSideConnectivity()
ar.BindArrayToTexture('side_local', side_local)
cell_parametrics = cg.GetCellType('vtkDGTet').GetReferencePoints()
ar.BindArrayToTexture('cell_parametrics', cell_parametrics)

# 1. Bind (cell,side) tuples
sideConn = cg.GetAttributes(vtkStringToken('triangle sides of vtkDGTet')).GetScalars()
ar.BindArrayToTexture(vtkStringToken('sides'), sideConn)
ar.SetNumberOfInstances(sideConn.GetNumberOfTuples())

# 2. Bind attribute data (connectivity and value arrays)
fr = [1, -1] # field range (defaulted to invalid range)
for attId in cg.GetUnorderedCellAttributeIds():
    cellAtt = cg.GetCellAttributeById(attId)
    print(cellAtt.GetName().Data())
    conn = cellAtt.GetArrayForCellTypeAndRole('vtkDGTet', 'connectivity')
    vals = cellAtt.GetArrayForCellTypeAndRole('vtkDGTet', 'values')
    # Note: Since we are rendering a single cell-shape at a time, we do
    #       not include the cell type-name in the texture sampler name.
    cname = vtkStringToken(cellAtt.GetName().Data() + '_conn')
    vname = vtkStringToken(cellAtt.GetName().Data() + '_vals')
    # ar.BindArrayToTexture(cname, conn, True) # Reshape to a 1-D array with 1 component per tuple.
    # ar.BindArrayToTexture(vname, vals, False)
    # print('  Binding "%s" and "%s"' % (cname.Data(), vname.Data()))
    if cellAtt.GetName() == cellAttName:
        cname = vtkStringToken('field_conn')
        vname = vtkStringToken('field_vals')
        ar.BindArrayToTexture(cname, conn, True) # Reshape to a 1-D array with 1 component per tuple.
        ar.BindArrayToTexture(vname, vals, True) # Always reshape since #comps can be > 4.
        ar.PrepareColormap(None)
        # Get the range of the field and, if invalid, reset to a valid default range centered around 0.
        cg.GetCellAttributeRange(cellAtt, 0, fr, True)
        if fr[0] > fr[1]:
            fr = [-1e-11, 1e-11]
        print('fr', fr)
        ac.GetShaderProperty().GetFragmentCustomUniforms().SetUniform3f('field_range', (fr[0], fr[1], fr[1] - fr[0]))
        print('  Binding "%s" and "%s" for "%s"' % \
            (cname.Data(), vname.Data(), cellAttName.Data()))
        print('    Range [%g, %g] %g' % (fr[0], fr[1], fr[1] - fr[0]))
    elif cellAtt == cg.GetShapeAttribute():
        cname = vtkStringToken('shape_conn')
        vname = vtkStringToken('shape_vals')
        ar.BindArrayToTexture(cname, conn, True) # Reshape to a 1-D array with 1 component per tuple.
        ar.BindArrayToTexture(vname, vals, False)
        print('  Binding "%s" and "%s" for "%s", shape_vals size (%d vals x %d bytes/val]' % (cname.Data(), vname.Data(), cellAtt.GetName().Data(), vals.GetMaxId()+1, vals.GetDataTypeSize()))

# Add a unit cube centered at the origin to the scene
cs = vtkCubeSource()
cf = vtkOutlineCornerFilter()
ca = vtkActor()
cm = vtkPolyDataMapper()
ca.SetMapper(cm)
cf.SetInputConnection(cs.GetOutputPort())
cm.SetInputConnection(cf.GetOutputPort())
rr.AddActor(ca)

# Final scene prep
rr.ResetCamera()
rr.SetBackground(0.5, 0.5, 0.8) # Something that both black and white contrast with.
ow.SetParentRenderer(rr)
ri.Initialize()
ow.On()
rw.Render()

# If you want to see the final shader sources with all of VTK's
# automated replacements, uncomment this line. You can also edit
# the files and re-run to try our modifications. Just be careful
# as the existence of these files will affect future runs of
# this script if they exist.
# ar.GetShaderProgram().SetFileNamePrefixForDebugging('/tmp/foo')

# Run the interactor
if interact:
    ri.Start()
else:
    Testing.processCmdLine()
    Testing.compareImage(rw, Testing.getAbsImagePath('TestArrayRenderer.png'))



#!/usr/bin/env python
from vtkmodules.vtkCommonCore import vtkPoints
from vtkmodules.vtkCommonTransforms import vtkThinPlateSplineTransform
from vtkmodules.vtkIOImage import vtkImageReader
from vtkmodules.vtkImagingCore import (
    vtkImageCacheFilter,
    vtkImageReslice,
)
from vtkmodules.vtkInteractionImage import vtkImageViewer
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Image pipeline
reader = vtkImageReader()
reader.ReleaseDataFlagOff()
reader.SetDataByteOrderToLittleEndian()
reader.SetDataExtent(0,63,0,63,1,93)
reader.SetDataSpacing(3.2,3.2,1.5)
reader.SetDataOrigin(-100.8,-100.8,-69)
reader.SetFilePrefix(VTK_DATA_ROOT + "/Data/headsq/quarter")
reader.SetDataMask(0x7fff)
reader.Update()
p1 = vtkPoints()
p2 = vtkPoints()
p1.InsertNextPoint(0,0,0)
p2.InsertNextPoint(-60,10,20)
p1.InsertNextPoint(-100,-100,-50)
p2.InsertNextPoint(-100,-100,-50)
p1.InsertNextPoint(-100,-100,50)
p2.InsertNextPoint(-100,-100,50)
p1.InsertNextPoint(-100,100,-50)
p2.InsertNextPoint(-100,100,-50)
p1.InsertNextPoint(-100,100,50)
p2.InsertNextPoint(-100,100,50)
p1.InsertNextPoint(100,-100,-50)
p2.InsertNextPoint(100,-100,-50)
p1.InsertNextPoint(100,-100,50)
p2.InsertNextPoint(100,-100,50)
p1.InsertNextPoint(100,100,-50)
p2.InsertNextPoint(100,100,-50)
p1.InsertNextPoint(100,100,50)
p2.InsertNextPoint(100,100,50)
transform = vtkThinPlateSplineTransform()
transform.SetSourceLandmarks(p1)
transform.SetTargetLandmarks(p2)
transform.SetBasisToR()
reslice = vtkImageReslice()
reslice.SetInputConnection(reader.GetOutputPort())
reslice.SetResliceTransform(transform)
reslice.SetInterpolationModeToLinear()
reslice.SetOutputSpacing(1,1,1)
cac = vtkImageCacheFilter()
cac.SetInputConnection(reslice.GetOutputPort())
cac.SetCacheSize(1000)
cac.SetInputConnection(reslice.GetOutputPort())
viewer = vtkImageViewer()
viewer.SetInputConnection(cac.GetOutputPort())
viewer.SetZSlice(90)
viewer.SetColorWindow(2000)
viewer.SetColorLevel(1000)
viewer.SetSize(200,200)
viewer.Render()
# --- end of script --



#!/usr/bin/env python
# -*- coding: utf-8 -*-


from vtkmodules.vtkCommonColor import vtkNamedColors
from vtkmodules.vtkFiltersCore import vtkGlyph3D
from vtkmodules.vtkFiltersSources import (
    vtkConeSource,
    vtkSphereSource,
)
from vtkmodules.vtkRenderingCore import (
    vtkInteractorEventRecorder,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
from vtkmodules.vtkRenderingLOD import vtkLODActor
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
import vtkmodules.test.Testing

# Make grabbing color a little easier
def GetRGBColor(colorName):
    '''
        Return the red, green and blue components for a
        color as doubles.
    '''
    rgb = [0.0, 0.0, 0.0]  # black
    vtkNamedColors().GetColorRGB(colorName, rgb)
    return rgb

# Create a sphere source and actor
sphere = vtkSphereSource()

sphereMapper = vtkPolyDataMapper()
sphereMapper.SetInputConnection(sphere.GetOutputPort())

sphereActor = vtkLODActor()
sphereActor.SetMapper(sphereMapper)

sphereActor.GetProperty().SetDiffuseColor(GetRGBColor('banana'))
sphereActor.GetProperty().SetSpecular(.4)
sphereActor.GetProperty().SetSpecularPower(20)

# Create the spikes using a cone source and the sphere source

cone = vtkConeSource()
cone.SetResolution(20)

glyph = vtkGlyph3D()
glyph.SetInputConnection(sphere.GetOutputPort())
glyph.SetSourceConnection(cone.GetOutputPort())
glyph.SetVectorModeToUseNormal()
glyph.SetScaleModeToScaleByVector()
glyph.SetScaleFactor(0.25)

spikeMapper = vtkPolyDataMapper()
spikeMapper.SetInputConnection(glyph.GetOutputPort())

spikeActor = vtkLODActor()
spikeActor.SetMapper(spikeMapper)

spikeActor.GetProperty().SetDiffuseColor(GetRGBColor('tomato'))
spikeActor.GetProperty().SetSpecular(.4)
spikeActor.GetProperty().SetSpecularPower(20)

# Render the image

# Create the RenderWindow, Renderer and both Actors
#
ren = vtkRenderer()
renWin = vtkRenderWindow()
renWin.SetMultiSamples(0)
renWin.AddRenderer(ren)

iRen = vtkRenderWindowInteractor()
iRen.SetRenderWindow(renWin)

ren.AddActor(sphereActor)
ren.AddActor(spikeActor)
ren.SetBackground(0.1, 0.2, 0.4)

cam1 = ren.GetActiveCamera()
cam1.Zoom(1.4)
cam1.Azimuth(30)
cam1.Elevation(30)
ren.ResetCamera()

# Setup for recording
renWin.Render()

Recording = \
    "# StreamVersion 1.1\n\
    KeyPressEvent 165 173 0 106 1 j\n\
    CharEvent 165 173 0 106 1 j\n\
    KeyReleaseEvent 165 173 0 106 1 j\n\
    KeyPressEvent 165 173 0 97 1 a\n\
    CharEvent 165 173 0 97 1 a\n\
    KeyReleaseEvent 165 173 0 97 1 a\n\
    MouseMoveEvent 164 173 0 0 0 a\n\
    MouseMoveEvent 162 173 0 0 0 a\n\
    MouseMoveEvent 161 173 0 0 0 a\n\
    MouseMoveEvent 159 173 0 0 0 a\n\
    MouseMoveEvent 157 173 0 0 0 a\n\
    MouseMoveEvent 156 173 0 0 0 a\n\
    MouseMoveEvent 156 172 0 0 0 a\n\
    MouseMoveEvent 155 172 0 0 0 a\n\
    MouseMoveEvent 153 172 0 0 0 a\n\
    MouseMoveEvent 151 172 0 0 0 a\n\
    MouseMoveEvent 151 172 0 0 0 a\n\
    MouseMoveEvent 151 171 0 0 0 a\n\
    MouseMoveEvent 150 170 0 0 0 a\n\
    MouseMoveEvent 149 169 0 0 0 a\n\
    MouseMoveEvent 149 168 0 0 0 a\n\
    MouseMoveEvent 148 168 0 0 0 a\n\
    MouseMoveEvent 148 167 0 0 0 a\n\
    MouseMoveEvent 148 167 0 0 0 a\n\
    MouseMoveEvent 147 166 0 0 0 a\n\
    MouseMoveEvent 147 165 0 0 0 a\n\
    MouseMoveEvent 147 164 0 0 0 a\n\
    MouseMoveEvent 147 163 0 0 0 a\n\
    MouseMoveEvent 147 162 0 0 0 a\n\
    MouseMoveEvent 147 161 0 0 0 a\n\
    MouseMoveEvent 146 160 0 0 0 a\n\
    MouseMoveEvent 146 158 0 0 0 a\n\
    MouseMoveEvent 146 156 0 0 0 a\n\
    MouseMoveEvent 146 153 0 0 0 a\n\
    MouseMoveEvent 146 150 0 0 0 a\n\
    MouseMoveEvent 145 148 0 0 0 a\n\
    MouseMoveEvent 144 145 0 0 0 a\n\
    MouseMoveEvent 144 142 0 0 0 a\n\
    MouseMoveEvent 143 139 0 0 0 a\n\
    MouseMoveEvent 142 137 0 0 0 a\n\
    MouseMoveEvent 142 135 0 0 0 a\n\
    MouseMoveEvent 141 133 0 0 0 a\n\
    MouseMoveEvent 141 131 0 0 0 a\n\
    MouseMoveEvent 141 130 0 0 0 a\n\
    MouseMoveEvent 141 128 0 0 0 a\n\
    MouseMoveEvent 141 126 0 0 0 a\n\
    MouseMoveEvent 140 125 0 0 0 a\n\
    MouseMoveEvent 140 124 0 0 0 a\n\
    MouseMoveEvent 140 122 0 0 0 a\n\
    MouseMoveEvent 139 120 0 0 0 a\n\
    MouseMoveEvent 138 118 0 0 0 a\n\
    MouseMoveEvent 138 116 0 0 0 a\n\
    MouseMoveEvent 137 115 0 0 0 a\n\
    MouseMoveEvent 136 114 0 0 0 a\n\
    MouseMoveEvent 136 113 0 0 0 a\n\
    MouseMoveEvent 136 110 0 0 0 a\n\
    MouseMoveEvent 135 109 0 0 0 a\n\
    MouseMoveEvent 135 107 0 0 0 a\n\
    MouseMoveEvent 134 105 0 0 0 a\n\
    MouseMoveEvent 134 103 0 0 0 a\n\
    MouseMoveEvent 133 101 0 0 0 a\n\
    MouseMoveEvent 133 100 0 0 0 a\n\
    MouseMoveEvent 132 98 0 0 0 a\n\
    MouseMoveEvent 131 97 0 0 0 a\n\
    MouseMoveEvent 131 96 0 0 0 a\n\
    MouseMoveEvent 131 95 0 0 0 a\n\
    MouseMoveEvent 130 93 0 0 0 a\n\
    MouseMoveEvent 129 92 0 0 0 a\n\
    MouseMoveEvent 129 91 0 0 0 a\n\
    MouseMoveEvent 129 90 0 0 0 a\n\
    MouseMoveEvent 129 89 0 0 0 a\n\
    MouseMoveEvent 128 88 0 0 0 a\n\
    MouseMoveEvent 128 88 0 0 0 a\n\
    MouseMoveEvent 129 88 0 0 0 a\n\
    MiddleButtonPressEvent 129 88 0 0 0 a\n\
    StartInteractionEvent 129 88 0 0 0 a\n\
    TimerEvent 129 88 0 0 0 a\n\
    TimerEvent 129 88 0 0 0 a\n\
    TimerEvent 129 88 0 0 0 a\n\
    TimerEvent 129 88 0 0 0 a\n\
    TimerEvent 129 88 0 0 0 a\n\
    TimerEvent 129 88 0 0 0 a\n\
    MouseMoveEvent 129 87 0 0 0 a\n\
    InteractionEvent 129 87 0 0 0 a\n\
    TimerEvent 129 87 0 0 0 a\n\
    TimerEvent 129 87 0 0 0 a\n\
    TimerEvent 129 87 0 0 0 a\n\
    TimerEvent 129 87 0 0 0 a\n\
    TimerEvent 129 87 0 0 0 a\n\
    TimerEvent 129 87 0 0 0 a\n\
    TimerEvent 129 87 0 0 0 a\n\
    TimerEvent 129 87 0 0 0 a\n\
    MouseMoveEvent 129 87 0 0 0 a\n\
    InteractionEvent 129 87 0 0 0 a\n\
    TimerEvent 129 87 0 0 0 a\n\
    TimerEvent 129 87 0 0 0 a\n\
    TimerEvent 129 87 0 0 0 a\n\
    MouseMoveEvent 129 87 0 0 0 a\n\
    InteractionEvent 129 87 0 0 0 a\n\
    TimerEvent 129 87 0 0 0 a\n\
    MouseMoveEvent 129 86 0 0 0 a\n\
    InteractionEvent 129 86 0 0 0 a\n\
    TimerEvent 129 86 0 0 0 a\n\
    MouseMoveEvent 129 84 0 0 0 a\n\
    InteractionEvent 129 84 0 0 0 a\n\
    TimerEvent 129 84 0 0 0 a\n\
    MouseMoveEvent 128 81 0 0 0 a\n\
    InteractionEvent 128 81 0 0 0 a\n\
    TimerEvent 128 81 0 0 0 a\n\
    MouseMoveEvent 127 79 0 0 0 a\n\
    InteractionEvent 127 79 0 0 0 a\n\
    TimerEvent 127 79 0 0 0 a\n\
    MouseMoveEvent 127 75 0 0 0 a\n\
    InteractionEvent 127 75 0 0 0 a\n\
    TimerEvent 127 75 0 0 0 a\n\
    MouseMoveEvent 126 71 0 0 0 a\n\
    InteractionEvent 126 71 0 0 0 a\n\
    TimerEvent 126 71 0 0 0 a\n\
    MouseMoveEvent 125 71 0 0 0 a\n\
    InteractionEvent 125 71 0 0 0 a\n\
    TimerEvent 125 71 0 0 0 a\n\
    MouseMoveEvent 125 69 0 0 0 a\n\
    InteractionEvent 125 69 0 0 0 a\n\
    TimerEvent 125 69 0 0 0 a\n\
    TimerEvent 125 69 0 0 0 a\n\
    TimerEvent 125 69 0 0 0 a\n\
    TimerEvent 125 69 0 0 0 a\n\
    TimerEvent 125 69 0 0 0 a\n\
    TimerEvent 125 69 0 0 0 a\n\
    TimerEvent 125 69 0 0 0 a\n\
    TimerEvent 125 69 0 0 0 a\n\
    TimerEvent 125 69 0 0 0 a\n\
    TimerEvent 125 69 0 0 0 a\n\
    TimerEvent 125 69 0 0 0 a\n\
    TimerEvent 125 69 0 0 0 a\n\
    TimerEvent 125 69 0 0 0 a\n\
    TimerEvent 125 69 0 0 0 a\n\
    TimerEvent 125 69 0 0 0 a\n\
    TimerEvent 125 69 0 0 0 a\n\
    TimerEvent 125 69 0 0 0 a\n\
    MiddleButtonReleaseEvent 125 69 0 0 0 a\n\
    EndInteractionEvent 125 69 0 0 0 a\n\
    MouseMoveEvent 125 70 0 0 0 a\n\
    MouseMoveEvent 124 70 0 0 0 a\n\
    MouseMoveEvent 124 71 0 0 0 a\n\
    MouseMoveEvent 124 73 0 0 0 a\n\
    MouseMoveEvent 124 76 0 0 0 a\n\
    MouseMoveEvent 124 78 0 0 0 a\n\
    MouseMoveEvent 124 82 0 0 0 a\n\
    MouseMoveEvent 124 85 0 0 0 a\n\
    MouseMoveEvent 124 90 0 0 0 a\n\
    MouseMoveEvent 125 92 0 0 0 a\n\
    MouseMoveEvent 127 97 0 0 0 a\n\
    MouseMoveEvent 127 100 0 0 0 a\n\
    MouseMoveEvent 127 105 0 0 0 a\n\
    MouseMoveEvent 128 107 0 0 0 a\n\
    MouseMoveEvent 129 112 0 0 0 a\n\
    MouseMoveEvent 129 117 0 0 0 a\n\
    MouseMoveEvent 130 119 0 0 0 a\n\
    MouseMoveEvent 131 124 0 0 0 a\n\
    MouseMoveEvent 131 126 0 0 0 a\n\
    MouseMoveEvent 131 129 0 0 0 a\n\
    MouseMoveEvent 131 131 0 0 0 a\n\
    MouseMoveEvent 131 133 0 0 0 a\n\
    MouseMoveEvent 131 135 0 0 0 a\n\
    MouseMoveEvent 132 136 0 0 0 a\n\
    MouseMoveEvent 132 137 0 0 0 a\n\
    MouseMoveEvent 133 139 0 0 0 a\n\
    MouseMoveEvent 133 140 0 0 0 a\n\
    MouseMoveEvent 134 141 0 0 0 a\n\
    MouseMoveEvent 134 142 0 0 0 a\n\
    MouseMoveEvent 135 143 0 0 0 a\n\
    MouseMoveEvent 135 144 0 0 0 a\n\
    MouseMoveEvent 136 145 0 0 0 a\n\
    MouseMoveEvent 137 145 0 0 0 a\n\
    MouseMoveEvent 137 146 0 0 0 a\n\
    MouseMoveEvent 138 146 0 0 0 a\n\
    MouseMoveEvent 138 147 0 0 0 a\n\
    MouseMoveEvent 139 148 0 0 0 a\n\
    MiddleButtonPressEvent 139 148 0 0 0 a\n\
    StartInteractionEvent 139 148 0 0 0 a\n\
    TimerEvent 139 148 0 0 0 a\n\
    TimerEvent 139 148 0 0 0 a\n\
    TimerEvent 139 148 0 0 0 a\n\
    MouseMoveEvent 139 148 0 0 0 a\n\
    InteractionEvent 139 148 0 0 0 a\n\
    TimerEvent 139 148 0 0 0 a\n\
    TimerEvent 139 148 0 0 0 a\n\
    MouseMoveEvent 139 149 0 0 0 a\n\
    InteractionEvent 139 149 0 0 0 a\n\
    TimerEvent 139 149 0 0 0 a\n\
    MouseMoveEvent 141 151 0 0 0 a\n\
    InteractionEvent 141 151 0 0 0 a\n\
    TimerEvent 141 151 0 0 0 a\n\
    MouseMoveEvent 142 154 0 0 0 a\n\
    InteractionEvent 142 154 0 0 0 a\n\
    TimerEvent 142 154 0 0 0 a\n\
    MouseMoveEvent 144 155 0 0 0 a\n\
    InteractionEvent 144 155 0 0 0 a\n\
    TimerEvent 144 155 0 0 0 a\n\
    MouseMoveEvent 146 157 0 0 0 a\n\
    InteractionEvent 146 157 0 0 0 a\n\
    TimerEvent 146 157 0 0 0 a\n\
    MouseMoveEvent 146 160 0 0 0 a\n\
    InteractionEvent 146 160 0 0 0 a\n\
    TimerEvent 146 160 0 0 0 a\n\
    MouseMoveEvent 148 162 0 0 0 a\n\
    InteractionEvent 148 162 0 0 0 a\n\
    TimerEvent 148 162 0 0 0 a\n\
    MouseMoveEvent 149 164 0 0 0 a\n\
    InteractionEvent 149 164 0 0 0 a\n\
    TimerEvent 149 164 0 0 0 a\n\
    MouseMoveEvent 150 165 0 0 0 a\n\
    InteractionEvent 150 165 0 0 0 a\n\
    TimerEvent 150 165 0 0 0 a\n\
    MouseMoveEvent 151 167 0 0 0 a\n\
    InteractionEvent 151 167 0 0 0 a\n\
    TimerEvent 151 167 0 0 0 a\n\
    MouseMoveEvent 152 168 0 0 0 a\n\
    InteractionEvent 152 168 0 0 0 a\n\
    TimerEvent 152 168 0 0 0 a\n\
    MouseMoveEvent 153 170 0 0 0 a\n\
    InteractionEvent 153 170 0 0 0 a\n\
    TimerEvent 153 170 0 0 0 a\n\
    TimerEvent 153 170 0 0 0 a\n\
    MouseMoveEvent 155 172 0 0 0 a\n\
    InteractionEvent 155 172 0 0 0 a\n\
    TimerEvent 155 172 0 0 0 a\n\
    MouseMoveEvent 156 173 0 0 0 a\n\
    InteractionEvent 156 173 0 0 0 a\n\
    TimerEvent 156 173 0 0 0 a\n\
    MouseMoveEvent 158 176 0 0 0 a\n\
    InteractionEvent 158 176 0 0 0 a\n\
    TimerEvent 158 176 0 0 0 a\n\
    MouseMoveEvent 160 179 0 0 0 a\n\
    InteractionEvent 160 179 0 0 0 a\n\
    TimerEvent 160 179 0 0 0 a\n\
    MouseMoveEvent 162 181 0 0 0 a\n\
    InteractionEvent 162 181 0 0 0 a\n\
    TimerEvent 162 181 0 0 0 a\n\
    MouseMoveEvent 165 183 0 0 0 a\n\
    InteractionEvent 165 183 0 0 0 a\n\
    TimerEvent 165 183 0 0 0 a\n\
    MouseMoveEvent 166 184 0 0 0 a\n\
    InteractionEvent 166 184 0 0 0 a\n\
    TimerEvent 166 184 0 0 0 a\n\
    TimerEvent 166 184 0 0 0 a\n\
    MouseMoveEvent 166 185 0 0 0 a\n\
    InteractionEvent 166 185 0 0 0 a\n\
    TimerEvent 166 185 0 0 0 a\n\
    MouseMoveEvent 167 185 0 0 0 a\n\
    InteractionEvent 167 185 0 0 0 a\n\
    TimerEvent 167 185 0 0 0 a\n\
    TimerEvent 167 185 0 0 0 a\n\
    MouseMoveEvent 168 185 0 0 0 a\n\
    InteractionEvent 168 185 0 0 0 a\n\
    TimerEvent 168 185 0 0 0 a\n\
    MouseMoveEvent 168 186 0 0 0 a\n\
    InteractionEvent 168 186 0 0 0 a\n\
    TimerEvent 168 186 0 0 0 a\n\
    MouseMoveEvent 170 186 0 0 0 a\n\
    InteractionEvent 170 186 0 0 0 a\n\
    TimerEvent 170 186 0 0 0 a\n\
    MouseMoveEvent 171 187 0 0 0 a\n\
    InteractionEvent 171 187 0 0 0 a\n\
    TimerEvent 171 187 0 0 0 a\n\
    MouseMoveEvent 171 188 0 0 0 a\n\
    InteractionEvent 171 188 0 0 0 a\n\
    TimerEvent 171 188 0 0 0 a\n\
    TimerEvent 171 188 0 0 0 a\n\
    MouseMoveEvent 172 190 0 0 0 a\n\
    InteractionEvent 172 190 0 0 0 a\n\
    TimerEvent 172 190 0 0 0 a\n\
    MouseMoveEvent 173 190 0 0 0 a\n\
    InteractionEvent 173 190 0 0 0 a\n\
    TimerEvent 173 190 0 0 0 a\n\
    MouseMoveEvent 175 192 0 0 0 a\n\
    InteractionEvent 175 192 0 0 0 a\n\
    TimerEvent 175 192 0 0 0 a\n\
    MouseMoveEvent 175 193 0 0 0 a\n\
    InteractionEvent 175 193 0 0 0 a\n\
    TimerEvent 175 193 0 0 0 a\n\
    MouseMoveEvent 176 194 0 0 0 a\n\
    InteractionEvent 176 194 0 0 0 a\n\
    TimerEvent 176 194 0 0 0 a\n\
    MouseMoveEvent 177 194 0 0 0 a\n\
    InteractionEvent 177 194 0 0 0 a\n\
    TimerEvent 177 194 0 0 0 a\n\
    MouseMoveEvent 177 196 0 0 0 a\n\
    InteractionEvent 177 196 0 0 0 a\n\
    TimerEvent 177 196 0 0 0 a\n\
    MouseMoveEvent 178 196 0 0 0 a\n\
    InteractionEvent 178 196 0 0 0 a\n\
    TimerEvent 178 196 0 0 0 a\n\
    MouseMoveEvent 179 196 0 0 0 a\n\
    InteractionEvent 179 196 0 0 0 a\n\
    TimerEvent 179 196 0 0 0 a\n\
    TimerEvent 179 196 0 0 0 a\n\
    MouseMoveEvent 179 197 0 0 0 a\n\
    InteractionEvent 179 197 0 0 0 a\n\
    TimerEvent 179 197 0 0 0 a\n\
    TimerEvent 179 197 0 0 0 a\n\
    TimerEvent 179 197 0 0 0 a\n\
    MouseMoveEvent 179 198 0 0 0 a\n\
    InteractionEvent 179 198 0 0 0 a\n\
    TimerEvent 179 198 0 0 0 a\n\
    TimerEvent 179 198 0 0 0 a\n\
    MouseMoveEvent 179 198 0 0 0 a\n\
    InteractionEvent 179 198 0 0 0 a\n\
    TimerEvent 179 198 0 0 0 a\n\
    TimerEvent 179 198 0 0 0 a\n\
    TimerEvent 179 198 0 0 0 a\n\
    TimerEvent 179 198 0 0 0 a\n\
    MouseMoveEvent 180 198 0 0 0 a\n\
    InteractionEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    MiddleButtonReleaseEvent 180 198 0 0 0 a\n\
    EndInteractionEvent 180 198 0 0 0 a\n\
    MouseMoveEvent 180 198 0 0 0 a\n\
    LeftButtonPressEvent 180 198 0 0 0 a\n\
    StartInteractionEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    TimerEvent 180 198 0 0 0 a\n\
    MouseMoveEvent 179 198 0 0 0 a\n\
    InteractionEvent 179 198 0 0 0 a\n\
    TimerEvent 179 198 0 0 0 a\n\
    TimerEvent 179 198 0 0 0 a\n\
    TimerEvent 179 198 0 0 0 a\n\
    TimerEvent 179 198 0 0 0 a\n\
    TimerEvent 179 198 0 0 0 a\n\
    TimerEvent 179 198 0 0 0 a\n\
    TimerEvent 179 198 0 0 0 a\n\
    TimerEvent 179 198 0 0 0 a\n\
    MouseMoveEvent 179 198 0 0 0 a\n\
    InteractionEvent 179 198 0 0 0 a\n\
    TimerEvent 179 198 0 0 0 a\n\
    MouseMoveEvent 178 198 0 0 0 a\n\
    InteractionEvent 178 198 0 0 0 a\n\
    TimerEvent 178 198 0 0 0 a\n\
    MouseMoveEvent 176 198 0 0 0 a\n\
    InteractionEvent 176 198 0 0 0 a\n\
    TimerEvent 176 198 0 0 0 a\n\
    MouseMoveEvent 174 197 0 0 0 a\n\
    InteractionEvent 174 197 0 0 0 a\n\
    TimerEvent 174 197 0 0 0 a\n\
    MouseMoveEvent 170 197 0 0 0 a\n\
    InteractionEvent 170 197 0 0 0 a\n\
    TimerEvent 170 197 0 0 0 a\n\
    MouseMoveEvent 167 197 0 0 0 a\n\
    InteractionEvent 167 197 0 0 0 a\n\
    TimerEvent 167 197 0 0 0 a\n\
    MouseMoveEvent 164 196 0 0 0 a\n\
    InteractionEvent 164 196 0 0 0 a\n\
    TimerEvent 164 196 0 0 0 a\n\
    MouseMoveEvent 160 196 0 0 0 a\n\
    InteractionEvent 160 196 0 0 0 a\n\
    TimerEvent 160 196 0 0 0 a\n\
    MouseMoveEvent 154 196 0 0 0 a\n\
    InteractionEvent 154 196 0 0 0 a\n\
    TimerEvent 154 196 0 0 0 a\n\
    MouseMoveEvent 146 195 0 0 0 a\n\
    InteractionEvent 146 195 0 0 0 a\n\
    TimerEvent 146 195 0 0 0 a\n\
    MouseMoveEvent 134 195 0 0 0 a\n\
    InteractionEvent 134 195 0 0 0 a\n\
    TimerEvent 134 195 0 0 0 a\n\
    MouseMoveEvent 128 195 0 0 0 a\n\
    InteractionEvent 128 195 0 0 0 a\n\
    TimerEvent 128 195 0 0 0 a\n\
    MouseMoveEvent 124 194 0 0 0 a\n\
    InteractionEvent 124 194 0 0 0 a\n\
    TimerEvent 124 194 0 0 0 a\n\
    MouseMoveEvent 122 194 0 0 0 a\n\
    InteractionEvent 122 194 0 0 0 a\n\
    TimerEvent 122 194 0 0 0 a\n\
    MouseMoveEvent 120 194 0 0 0 a\n\
    InteractionEvent 120 194 0 0 0 a\n\
    TimerEvent 120 194 0 0 0 a\n\
    TimerEvent 120 194 0 0 0 a\n\
    MouseMoveEvent 119 193 0 0 0 a\n\
    InteractionEvent 119 193 0 0 0 a\n\
    TimerEvent 119 193 0 0 0 a\n\
    MouseMoveEvent 119 193 0 0 0 a\n\
    InteractionEvent 119 193 0 0 0 a\n\
    TimerEvent 119 193 0 0 0 a\n\
    TimerEvent 119 193 0 0 0 a\n\
    TimerEvent 119 193 0 0 0 a\n\
    TimerEvent 119 193 0 0 0 a\n\
    TimerEvent 119 193 0 0 0 a\n\
    MouseMoveEvent 117 193 0 0 0 a\n\
    InteractionEvent 117 193 0 0 0 a\n\
    TimerEvent 117 193 0 0 0 a\n\
    TimerEvent 117 193 0 0 0 a\n\
    MouseMoveEvent 113 192 0 0 0 a\n\
    InteractionEvent 113 192 0 0 0 a\n\
    TimerEvent 113 192 0 0 0 a\n\
    MouseMoveEvent 110 192 0 0 0 a\n\
    InteractionEvent 110 192 0 0 0 a\n\
    TimerEvent 110 192 0 0 0 a\n\
    MouseMoveEvent 108 192 0 0 0 a\n\
    InteractionEvent 108 192 0 0 0 a\n\
    TimerEvent 108 192 0 0 0 a\n\
    MouseMoveEvent 105 192 0 0 0 a\n\
    InteractionEvent 105 192 0 0 0 a\n\
    TimerEvent 105 192 0 0 0 a\n\
    MouseMoveEvent 103 191 0 0 0 a\n\
    InteractionEvent 103 191 0 0 0 a\n\
    TimerEvent 103 191 0 0 0 a\n\
    MouseMoveEvent 100 191 0 0 0 a\n\
    InteractionEvent 100 191 0 0 0 a\n\
    TimerEvent 100 191 0 0 0 a\n\
    MouseMoveEvent 98 191 0 0 0 a\n\
    InteractionEvent 98 191 0 0 0 a\n\
    TimerEvent 98 191 0 0 0 a\n\
    MouseMoveEvent 94 190 0 0 0 a\n\
    InteractionEvent 94 190 0 0 0 a\n\
    TimerEvent 94 190 0 0 0 a\n\
    MouseMoveEvent 89 190 0 0 0 a\n\
    InteractionEvent 89 190 0 0 0 a\n\
    TimerEvent 89 190 0 0 0 a\n\
    MouseMoveEvent 85 190 0 0 0 a\n\
    InteractionEvent 85 190 0 0 0 a\n\
    TimerEvent 85 190 0 0 0 a\n\
    MouseMoveEvent 81 189 0 0 0 a\n\
    InteractionEvent 81 189 0 0 0 a\n\
    TimerEvent 81 189 0 0 0 a\n\
    MouseMoveEvent 80 189 0 0 0 a\n\
    InteractionEvent 80 189 0 0 0 a\n\
    TimerEvent 80 189 0 0 0 a\n\
    MouseMoveEvent 79 189 0 0 0 a\n\
    InteractionEvent 79 189 0 0 0 a\n\
    TimerEvent 79 189 0 0 0 a\n\
    MouseMoveEvent 78 189 0 0 0 a\n\
    InteractionEvent 78 189 0 0 0 a\n\
    TimerEvent 78 189 0 0 0 a\n\
    TimerEvent 78 189 0 0 0 a\n\
    TimerEvent 78 189 0 0 0 a\n\
    MouseMoveEvent 76 189 0 0 0 a\n\
    InteractionEvent 76 189 0 0 0 a\n\
    TimerEvent 76 189 0 0 0 a\n\
    TimerEvent 76 189 0 0 0 a\n\
    MouseMoveEvent 73 189 0 0 0 a\n\
    InteractionEvent 73 189 0 0 0 a\n\
    TimerEvent 73 189 0 0 0 a\n\
    MouseMoveEvent 72 189 0 0 0 a\n\
    InteractionEvent 72 189 0 0 0 a\n\
    TimerEvent 72 189 0 0 0 a\n\
    MouseMoveEvent 71 189 0 0 0 a\n\
    InteractionEvent 71 189 0 0 0 a\n\
    TimerEvent 71 189 0 0 0 a\n\
    MouseMoveEvent 70 189 0 0 0 a\n\
    InteractionEvent 70 189 0 0 0 a\n\
    TimerEvent 70 189 0 0 0 a\n\
    MouseMoveEvent 69 189 0 0 0 a\n\
    InteractionEvent 69 189 0 0 0 a\n\
    TimerEvent 69 189 0 0 0 a\n\
    TimerEvent 69 189 0 0 0 a\n\
    MouseMoveEvent 69 189 0 0 0 a\n\
    InteractionEvent 69 189 0 0 0 a\n\
    TimerEvent 69 189 0 0 0 a\n\
    MouseMoveEvent 67 189 0 0 0 a\n\
    InteractionEvent 67 189 0 0 0 a\n\
    TimerEvent 67 189 0 0 0 a\n\
    MouseMoveEvent 66 189 0 0 0 a\n\
    InteractionEvent 66 189 0 0 0 a\n\
    TimerEvent 66 189 0 0 0 a\n\
    MouseMoveEvent 65 189 0 0 0 a\n\
    InteractionEvent 65 189 0 0 0 a\n\
    TimerEvent 65 189 0 0 0 a\n\
    MouseMoveEvent 63 189 0 0 0 a\n\
    InteractionEvent 63 189 0 0 0 a\n\
    TimerEvent 63 189 0 0 0 a\n\
    MouseMoveEvent 61 189 0 0 0 a\n\
    InteractionEvent 61 189 0 0 0 a\n\
    TimerEvent 61 189 0 0 0 a\n\
    MouseMoveEvent 60 189 0 0 0 a\n\
    InteractionEvent 60 189 0 0 0 a\n\
    TimerEvent 60 189 0 0 0 a\n\
    MouseMoveEvent 58 189 0 0 0 a\n\
    InteractionEvent 58 189 0 0 0 a\n\
    TimerEvent 58 189 0 0 0 a\n\
    MouseMoveEvent 56 189 0 0 0 a\n\
    InteractionEvent 56 189 0 0 0 a\n\
    TimerEvent 56 189 0 0 0 a\n\
    MouseMoveEvent 55 189 0 0 0 a\n\
    InteractionEvent 55 189 0 0 0 a\n\
    TimerEvent 55 189 0 0 0 a\n\
    MouseMoveEvent 54 189 0 0 0 a\n\
    InteractionEvent 54 189 0 0 0 a\n\
    TimerEvent 54 189 0 0 0 a\n\
    MouseMoveEvent 53 189 0 0 0 a\n\
    InteractionEvent 53 189 0 0 0 a\n\
    TimerEvent 53 189 0 0 0 a\n\
    MouseMoveEvent 52 189 0 0 0 a\n\
    InteractionEvent 52 189 0 0 0 a\n\
    TimerEvent 52 189 0 0 0 a\n\
    MouseMoveEvent 51 188 0 0 0 a\n\
    InteractionEvent 51 188 0 0 0 a\n\
    TimerEvent 51 188 0 0 0 a\n\
    TimerEvent 51 188 0 0 0 a\n\
    MouseMoveEvent 50 188 0 0 0 a\n\
    InteractionEvent 50 188 0 0 0 a\n\
    TimerEvent 50 188 0 0 0 a\n\
    TimerEvent 50 188 0 0 0 a\n\
    TimerEvent 50 188 0 0 0 a\n\
    TimerEvent 50 188 0 0 0 a\n\
    TimerEvent 50 188 0 0 0 a\n\
    TimerEvent 50 188 0 0 0 a\n\
    TimerEvent 50 188 0 0 0 a\n\
    TimerEvent 50 188 0 0 0 a\n\
    TimerEvent 50 188 0 0 0 a\n\
    TimerEvent 50 188 0 0 0 a\n\
    TimerEvent 50 188 0 0 0 a\n\
    TimerEvent 50 188 0 0 0 a\n\
    LeftButtonReleaseEvent 50 188 0 0 0 a\n\
    EndInteractionEvent 50 188 0 0 0 a\n\
    MouseMoveEvent 51 188 0 0 0 a\n\
    MouseMoveEvent 52 188 0 0 0 a\n\
    MouseMoveEvent 54 189 0 0 0 a\n\
    MouseMoveEvent 56 189 0 0 0 a\n\
    MouseMoveEvent 58 190 0 0 0 a\n\
    MouseMoveEvent 61 190 0 0 0 a\n\
    MouseMoveEvent 64 191 0 0 0 a\n\
    MouseMoveEvent 66 191 0 0 0 a\n\
    MouseMoveEvent 68 191 0 0 0 a\n\
    MouseMoveEvent 73 192 0 0 0 a\n\
    MouseMoveEvent 76 192 0 0 0 a\n\
    MouseMoveEvent 81 192 0 0 0 a\n\
    MouseMoveEvent 83 191 0 0 0 a\n\
    MouseMoveEvent 87 191 0 0 0 a\n\
    MouseMoveEvent 90 190 0 0 0 a\n\
    MouseMoveEvent 91 189 0 0 0 a\n\
    MouseMoveEvent 92 189 0 0 0 a\n\
    MouseMoveEvent 94 188 0 0 0 a\n\
    MouseMoveEvent 95 187 0 0 0 a\n\
    MouseMoveEvent 96 187 0 0 0 a\n\
    MouseMoveEvent 97 187 0 0 0 a\n\
    MouseMoveEvent 99 187 0 0 0 a\n\
    MouseMoveEvent 101 185 0 0 0 a\n\
    MouseMoveEvent 102 185 0 0 0 a\n\
    MouseMoveEvent 104 184 0 0 0 a\n\
    MouseMoveEvent 105 183 0 0 0 a\n\
    MouseMoveEvent 106 183 0 0 0 a\n\
    MouseMoveEvent 107 183 0 0 0 a\n\
    MouseMoveEvent 108 183 0 0 0 a\n\
    MouseMoveEvent 109 183 0 0 0 a\n\
    MouseMoveEvent 111 183 0 0 0 a\n\
    MouseMoveEvent 113 183 0 0 0 a\n\
    MouseMoveEvent 115 184 0 0 0 a\n\
    MouseMoveEvent 116 185 0 0 0 a\n\
    MouseMoveEvent 117 185 0 0 0 a\n\
    MouseMoveEvent 120 185 0 0 0 a\n\
    MouseMoveEvent 122 187 0 0 0 a\n\
    MouseMoveEvent 123 187 0 0 0 a\n\
    MouseMoveEvent 124 187 0 0 0 a\n\
    MouseMoveEvent 128 188 0 0 0 a\n\
    MouseMoveEvent 130 188 0 0 0 a\n\
    MouseMoveEvent 131 188 0 0 0 a\n\
    MouseMoveEvent 132 188 0 0 0 a\n\
    MouseMoveEvent 133 188 0 0 0 a\n\
    MouseMoveEvent 134 188 0 0 0 a\n\
    MouseMoveEvent 134 188 0 0 0 a\n\
    MouseMoveEvent 135 188 0 0 0 a\n\
    MouseMoveEvent 137 188 0 0 0 a\n\
    MouseMoveEvent 138 188 0 0 0 a\n\
    RightButtonPressEvent 138 188 0 0 0 a\n\
    StartInteractionEvent 138 188 0 0 0 a\n\
    TimerEvent 138 188 0 0 0 a\n\
    TimerEvent 138 188 0 0 0 a\n\
    TimerEvent 138 188 0 0 0 a\n\
    TimerEvent 138 188 0 0 0 a\n\
    TimerEvent 138 188 0 0 0 a\n\
    TimerEvent 138 188 0 0 0 a\n\
    TimerEvent 138 188 0 0 0 a\n\
    TimerEvent 138 188 0 0 0 a\n\
    TimerEvent 138 188 0 0 0 a\n\
    TimerEvent 138 188 0 0 0 a\n\
    TimerEvent 138 188 0 0 0 a\n\
    TimerEvent 138 188 0 0 0 a\n\
    TimerEvent 138 188 0 0 0 a\n\
    TimerEvent 138 188 0 0 0 a\n\
    TimerEvent 138 188 0 0 0 a\n\
    TimerEvent 138 188 0 0 0 a\n\
    TimerEvent 138 188 0 0 0 a\n\
    MouseMoveEvent 138 188 0 0 0 a\n\
    InteractionEvent 138 188 0 0 0 a\n\
    TimerEvent 138 188 0 0 0 a\n\
    MouseMoveEvent 137 188 0 0 0 a\n\
    InteractionEvent 137 188 0 0 0 a\n\
    TimerEvent 137 188 0 0 0 a\n\
    MouseMoveEvent 136 187 0 0 0 a\n\
    InteractionEvent 136 187 0 0 0 a\n\
    TimerEvent 136 187 0 0 0 a\n\
    MouseMoveEvent 133 185 0 0 0 a\n\
    InteractionEvent 133 185 0 0 0 a\n\
    TimerEvent 133 185 0 0 0 a\n\
    MouseMoveEvent 131 183 0 0 0 a\n\
    InteractionEvent 131 183 0 0 0 a\n\
    TimerEvent 131 183 0 0 0 a\n\
    MouseMoveEvent 128 180 0 0 0 a\n\
    InteractionEvent 128 180 0 0 0 a\n\
    TimerEvent 128 180 0 0 0 a\n\
    MouseMoveEvent 125 177 0 0 0 a\n\
    InteractionEvent 125 177 0 0 0 a\n\
    TimerEvent 125 177 0 0 0 a\n\
    MouseMoveEvent 123 175 0 0 0 a\n\
    InteractionEvent 123 175 0 0 0 a\n\
    TimerEvent 123 175 0 0 0 a\n\
    MouseMoveEvent 123 174 0 0 0 a\n\
    InteractionEvent 123 174 0 0 0 a\n\
    TimerEvent 123 174 0 0 0 a\n\
    MouseMoveEvent 121 172 0 0 0 a\n\
    InteractionEvent 121 172 0 0 0 a\n\
    TimerEvent 121 172 0 0 0 a\n\
    TimerEvent 121 172 0 0 0 a\n\
    MouseMoveEvent 121 171 0 0 0 a\n\
    InteractionEvent 121 171 0 0 0 a\n\
    TimerEvent 121 171 0 0 0 a\n\
    MouseMoveEvent 119 170 0 0 0 a\n\
    InteractionEvent 119 170 0 0 0 a\n\
    TimerEvent 119 170 0 0 0 a\n\
    TimerEvent 119 170 0 0 0 a\n\
    MouseMoveEvent 119 168 0 0 0 a\n\
    InteractionEvent 119 168 0 0 0 a\n\
    TimerEvent 119 168 0 0 0 a\n\
    MouseMoveEvent 118 167 0 0 0 a\n\
    InteractionEvent 118 167 0 0 0 a\n\
    TimerEvent 118 167 0 0 0 a\n\
    MouseMoveEvent 117 167 0 0 0 a\n\
    InteractionEvent 117 167 0 0 0 a\n\
    TimerEvent 117 167 0 0 0 a\n\
    TimerEvent 117 167 0 0 0 a\n\
    TimerEvent 117 167 0 0 0 a\n\
    TimerEvent 117 167 0 0 0 a\n\
    TimerEvent 117 167 0 0 0 a\n\
    TimerEvent 117 167 0 0 0 a\n\
    TimerEvent 117 167 0 0 0 a\n\
    TimerEvent 117 167 0 0 0 a\n\
    TimerEvent 117 167 0 0 0 a\n\
    TimerEvent 117 167 0 0 0 a\n\
    TimerEvent 117 167 0 0 0 a\n\
    TimerEvent 117 167 0 0 0 a\n\
    TimerEvent 117 167 0 0 0 a\n\
    TimerEvent 117 167 0 0 0 a\n\
    TimerEvent 117 167 0 0 0 a\n\
    TimerEvent 117 167 0 0 0 a\n\
    TimerEvent 117 167 0 0 0 a\n\
    MouseMoveEvent 116 166 0 0 0 a\n\
    InteractionEvent 116 166 0 0 0 a\n\
    TimerEvent 116 166 0 0 0 a\n\
    TimerEvent 116 166 0 0 0 a\n\
    TimerEvent 116 166 0 0 0 a\n\
    TimerEvent 116 166 0 0 0 a\n\
    TimerEvent 116 166 0 0 0 a\n\
    TimerEvent 116 166 0 0 0 a\n\
    MouseMoveEvent 116 167 0 0 0 a\n\
    InteractionEvent 116 167 0 0 0 a\n\
    TimerEvent 116 167 0 0 0 a\n\
    MouseMoveEvent 116 173 0 0 0 a\n\
    InteractionEvent 116 173 0 0 0 a\n\
    TimerEvent 116 173 0 0 0 a\n\
    MouseMoveEvent 116 178 0 0 0 a\n\
    InteractionEvent 116 178 0 0 0 a\n\
    TimerEvent 116 178 0 0 0 a\n\
    RightButtonReleaseEvent 116 176 0 0 0 a\n\
"

recorder = vtkInteractorEventRecorder()
recorder.SetInteractor(iRen)
recorder.SetFileName("record.log")
#recorder.On()
#recorder.Record()
recorder.ReadFromInputStringOn()
recorder.SetInputString(Recording)

# Render and play the events
recorder.Play()
iRen.Start()



#!/usr/bin/env python
from vtkmodules.vtkImagingCore import vtkImageCast
from vtkmodules.vtkImagingColor import (
    vtkImageHSIToRGB,
    vtkImageRGBToHSI,
)
from vtkmodules.vtkImagingSources import vtkImageCanvasSource2D
from vtkmodules.vtkInteractionImage import vtkImageViewer
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Use the painter to draw using colors.
# This is not a pipeline object.  It will support pipeline objects.
# Please do not use this object directly.
imageCanvas = vtkImageCanvasSource2D()
imageCanvas.SetNumberOfScalarComponents(3)
imageCanvas.SetScalarTypeToUnsignedChar()
imageCanvas.SetExtent(0,320,0,320,0,0)
imageCanvas.SetDrawColor(0,0,0)
imageCanvas.FillBox(0,511,0,511)
# r, g, b
imageCanvas.SetDrawColor(255,0,0)
imageCanvas.FillBox(0,50,0,100)
imageCanvas.SetDrawColor(128,128,0)
imageCanvas.FillBox(50,100,0,100)
imageCanvas.SetDrawColor(0,255,0)
imageCanvas.FillBox(100,150,0,100)
imageCanvas.SetDrawColor(0,128,128)
imageCanvas.FillBox(150,200,0,100)
imageCanvas.SetDrawColor(0,0,255)
imageCanvas.FillBox(200,250,0,100)
imageCanvas.SetDrawColor(128,0,128)
imageCanvas.FillBox(250,300,0,100)
# intensity scale
imageCanvas.SetDrawColor(5,5,5)
imageCanvas.FillBox(0,50,110,210)
imageCanvas.SetDrawColor(55,55,55)
imageCanvas.FillBox(50,100,110,210)
imageCanvas.SetDrawColor(105,105,105)
imageCanvas.FillBox(100,150,110,210)
imageCanvas.SetDrawColor(155,155,155)
imageCanvas.FillBox(150,200,110,210)
imageCanvas.SetDrawColor(205,205,205)
imageCanvas.FillBox(200,250,110,210)
imageCanvas.SetDrawColor(255,255,255)
imageCanvas.FillBox(250,300,110,210)
# saturation scale
imageCanvas.SetDrawColor(245,0,0)
imageCanvas.FillBox(0,50,220,320)
imageCanvas.SetDrawColor(213,16,16)
imageCanvas.FillBox(50,100,220,320)
imageCanvas.SetDrawColor(181,32,32)
imageCanvas.FillBox(100,150,220,320)
imageCanvas.SetDrawColor(149,48,48)
imageCanvas.FillBox(150,200,220,320)
imageCanvas.SetDrawColor(117,64,64)
imageCanvas.FillBox(200,250,220,320)
imageCanvas.SetDrawColor(85,80,80)
imageCanvas.FillBox(250,300,220,320)
convert = vtkImageRGBToHSI()
convert.SetInputConnection(imageCanvas.GetOutputPort())
convertBack = vtkImageHSIToRGB()
convertBack.SetInputConnection(convert.GetOutputPort())
cast = vtkImageCast()
cast.SetInputConnection(convertBack.GetOutputPort())
cast.SetOutputScalarTypeToFloat()
cast.ReleaseDataFlagOff()
viewer = vtkImageViewer()
viewer.SetInputConnection(convertBack.GetOutputPort())
#viewer SetInputConnection [imageCanvas GetOutputPort]
viewer.SetColorWindow(256)
viewer.SetColorLevel(127.5)
viewer.SetSize(320,320)
viewer.Render()
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkIOImage import (
    vtkBMPReader,
    vtkPNGReader,
)
from vtkmodules.vtkImagingCore import (
    vtkImageCast,
    vtkImageShiftScale,
)
from vtkmodules.vtkImagingGeneral import vtkImageGradient
from vtkmodules.vtkImagingMath import vtkImageDotProduct
from vtkmodules.vtkInteractionImage import vtkImageViewer
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# This script shows the magnitude of an image in frequency domain.
# Image pipeline
reader = vtkPNGReader()
reader.SetFileName(VTK_DATA_ROOT + "/Data/fullhead15.png")
cast = vtkImageCast()
cast.SetInputConnection(reader.GetOutputPort())
cast.SetOutputScalarTypeToFloat()
scale2 = vtkImageShiftScale()
scale2.SetInputConnection(cast.GetOutputPort())
scale2.SetScale(0.05)
gradient = vtkImageGradient()
gradient.SetInputConnection(scale2.GetOutputPort())
gradient.SetDimensionality(3)
gradient.Update()
pnm = vtkBMPReader()
pnm.SetFileName(VTK_DATA_ROOT + "/Data/masonry.bmp")
cast2 = vtkImageCast()
cast2.SetInputConnection(pnm.GetOutputPort())
cast2.SetOutputScalarTypeToDouble()
cast2.Update()
magnitude = vtkImageDotProduct()
magnitude.SetInput1Data(cast2.GetOutput())
magnitude.SetInput2Data(gradient.GetOutput())
#vtkImageViewer viewer
viewer = vtkImageViewer()
viewer.SetInputConnection(magnitude.GetOutputPort())
viewer.SetColorWindow(1000)
viewer.SetColorLevel(300)
#viewer DebugOn
viewer.Render()
# --- end of script --



#!/usr/bin/env python
import math
from vtkmodules.vtkCommonDataModel import vtkPolyData
from vtkmodules.vtkFiltersCore import vtkContourFilter
from vtkmodules.vtkIOParallel import vtkMultiBlockPLOT3DReader
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Graphics stuff
# Create the RenderWindow, Renderer and both Actors
#
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

pl3d = vtkMultiBlockPLOT3DReader()
pl3d.SetXYZFileName(VTK_DATA_ROOT + "/Data/combxyz.bin")
pl3d.SetQFileName(VTK_DATA_ROOT + "/Data/combq.bin")
pl3d.SetScalarFunctionNumber(100)
pl3d.SetVectorFunctionNumber(202)
pl3d.Update()

output = pl3d.GetOutput().GetBlock(0)

range = output.GetPointData().GetScalars().GetRange()
min = range[0]
max = range[1]
value = (min + max) / 2.0

cf = vtkContourFilter()
cf.SetInputData(output)
cf.SetValue(0, value)
cf.UseScalarTreeOn()

numberOfContours = 5
epsilon = float(max - min) / float(numberOfContours * 10)
min = min + epsilon
max = max - epsilon
i = 1
while i <= numberOfContours:
    cf.SetValue(0, min + ((i - 1) / float(numberOfContours - 1)) * (max - min))
    cf.Update()
    idx = str(i)
    exec("pd" + idx + " = vtkPolyData()")
    eval("pd" + idx).CopyStructure(cf.GetOutput())
    eval("pd" + idx).GetPointData().DeepCopy(cf.GetOutput().GetPointData())

    exec("mapper" + idx + " = vtkPolyDataMapper()")
    eval("mapper" + idx).SetInputData(eval("pd" + idx))
    eval("mapper" + idx).SetScalarRange(
      output.GetPointData().GetScalars().GetRange())

    exec("actor" + idx + " = vtkActor()")
    eval("actor" + idx).AddPosition(0, i * 12, 0)
    eval("actor" + idx).SetMapper(eval("mapper" + idx))

    ren1.AddActor(eval("actor" + idx))

    i += 1

# Add the actors to the renderer, set the background and size
#
ren1.SetBackground(.3, .3, .3)

renWin.SetSize(450, 150)

# cam1 = ren1.GetActiveCamera()
ren1.GetActiveCamera().SetPosition(-36.3762, 32.3855, 51.3652)
ren1.GetActiveCamera().SetFocalPoint(8.255, 33.3861, 29.7687)
ren1.GetActiveCamera().SetViewAngle(30)
ren1.GetActiveCamera().SetViewUp(0, 0, 1)
ren1.ResetCameraClippingRange()

iren.Initialize()
#iren.Start()



#!/usr/bin/env python
from vtkmodules.vtkFiltersCore import vtkTubeFilter
from vtkmodules.vtkFiltersModeling import vtkRibbonFilter
from vtkmodules.vtkIOImage import vtkPNGReader
from vtkmodules.vtkIOLegacy import vtkPolyDataReader
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
    vtkTexture,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# create pipeline
#
reader = vtkPolyDataReader()
reader.SetFileName(VTK_DATA_ROOT + "/Data/vtk.vtk")
# Read a ruler texture
r = vtkPNGReader()
r.SetFileName(VTK_DATA_ROOT + "/Data/ruler.png")
atext = vtkTexture()
atext.SetInputConnection(r.GetOutputPort())
atext.InterpolateOn()
# produce some ribbons
ribbon = vtkRibbonFilter()
ribbon.SetInputConnection(reader.GetOutputPort())
ribbon.SetWidth(0.1)
ribbon.SetGenerateTCoordsToUseLength()
ribbon.SetTextureLength(1.0)
ribbon.UseDefaultNormalOn()
ribbon.SetDefaultNormal(0,0,1)
ribbonMapper = vtkPolyDataMapper()
ribbonMapper.SetInputConnection(ribbon.GetOutputPort())
ribbonActor = vtkActor()
ribbonActor.SetMapper(ribbonMapper)
ribbonActor.GetProperty().SetColor(1,1,0)
ribbonActor.SetTexture(atext)
# produce some tubes
tuber = vtkTubeFilter()
tuber.SetInputConnection(reader.GetOutputPort())
tuber.SetRadius(0.1)
tuber.SetNumberOfSides(12)
tuber.SetGenerateTCoordsToUseLength()
tuber.SetTextureLength(0.5)
tuber.CappingOn()
tubeMapper = vtkPolyDataMapper()
tubeMapper.SetInputConnection(tuber.GetOutputPort())
tubeActor = vtkActor()
tubeActor.SetMapper(tubeMapper)
tubeActor.GetProperty().SetColor(1,1,0)
tubeActor.SetTexture(atext)
tubeActor.AddPosition(5,0,0)
# Create the RenderWindow, Renderer and both Actors
#
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)
# Add the actors to the renderer, set the background and size
#
ren1.AddActor(ribbonActor)
ren1.AddActor(tubeActor)
ren1.SetBackground(1,1,1)
renWin.SetSize(900,350)
ren1.SetBackground(1,1,1)
ren1.ResetCamera()
ren1.GetActiveCamera().Zoom(4)
# render the image
#
renWin.Render()
# prevent the tk window from showing up then start the event loop
threshold = 15
# --- end of script --



#!/usr/bin/env python
from GetReader import get_reader
from vtkmodules.vtkFiltersCore import (
    vtkAssignAttribute,
    vtkThreshold,
)
from vtkmodules.vtkFiltersGeometry import vtkDataSetSurfaceFilter
from vtkmodules.vtkIONetCDF import vtkNetCDFCFReader
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# This test checks netCDF reader.  It uses the COARDS convention.
# Open the file.
reader = get_reader(VTK_DATA_ROOT + "/Data/tos_O1_2001-2002.nc")
# Set the arrays we want to load.
reader.UpdateMetaData()
reader.SetVariableArrayStatus("tos",1)
reader.SetSphericalCoordinates(0)
reader.Update()

# Test unit field arrays
grid = reader.GetOutput()
tuarr = grid.GetFieldData().GetAbstractArray("time_units")
# xarray removes time_units from time variables relying on the type of the variable:
# datetime64 or cftime
if not tuarr and reader.GetAccessor().GetClassName() != 'vtkXArrayAccessor':
  print("Unable to retrieve time_units field array")
  exit(1)
tosuarr = grid.GetFieldData().GetAbstractArray("tos_units")
if not tosuarr:
  print("Unable to retrieve tos_units field array")
  exit(1)
if tosuarr.GetValue(0) != "K":
  print("tos_units is not K but " + tosuarr.GetValue(0))
  exit(1)

aa = vtkAssignAttribute()
aa.SetInputConnection(reader.GetOutputPort())
aa.Assign("tos","SCALARS","POINT_DATA")
thresh = vtkThreshold()
thresh.SetInputConnection(aa.GetOutputPort())
thresh.SetThresholdFunction(vtkThreshold.THRESHOLD_LOWER)
thresh.SetLowerThreshold(10000.0)

surface = vtkDataSetSurfaceFilter()
surface.SetInputConnection(thresh.GetOutputPort())
mapper = vtkPolyDataMapper()
mapper.SetInputConnection(surface.GetOutputPort())
mapper.SetScalarRange(270,310)
actor = vtkActor()
actor.SetMapper(mapper)
ren = vtkRenderer()
ren.AddActor(actor)
renWin = vtkRenderWindow()
renWin.SetSize(200,200)
renWin.AddRenderer(ren)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)
renWin.Render()
# # Setup a lookup table.
# vtkLookupTable lut
# lut SetTableRange 270 310
# lut SetHueRange 0.66 0.0
# lut SetRampToLinear
# # Make pretty colors
# vtkImageMapToColors map
# map SetInputConnection [asinine GetOutputPort]
# map SetLookupTable lut
# map SetOutputFormatToRGB
# # vtkImageViewer viewer
# # viewer SetInputConnection [map GetOutputPort]
# # viewer SetColorWindow 256
# # viewer SetColorLevel 127.5
# # viewer Render
# vtkImageViewer2 viewer
# viewer SetInputConnection [map GetOutputPort]
# viewer Render
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkFiltersGeometry import vtkGeometryFilter
from vtkmodules.vtkIOGeometry import vtkChacoReader
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# read in a Chaco file
chReader = vtkChacoReader()
chReader.SetBaseName(VTK_DATA_ROOT + "/Data/vwgt")
chReader.SetGenerateGlobalElementIdArray(1)
chReader.SetGenerateGlobalNodeIdArray(1)
chReader.SetGenerateEdgeWeightArrays(1)
chReader.SetGenerateVertexWeightArrays(1)

geom = vtkGeometryFilter()
geom.SetInputConnection(chReader.GetOutputPort())

mapper = vtkPolyDataMapper()
mapper.SetInputConnection(geom.GetOutputPort())
mapper.SetColorModeToMapScalars()
mapper.SetScalarModeToUsePointFieldData()
mapper.SelectColorArray("VertexWeight1")
mapper.SetScalarRange(1, 5)

actor0 = vtkActor()
actor0.SetMapper(mapper)

# Create the RenderWindow, Renderer and interactor
#
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

# Add the actor to the renderer, set the background and size
#
ren1.AddActor(actor0)
ren1.SetBackground(0, 0, 0)

renWin.SetSize(300, 300)
renWin.SetMultiSamples(0)

iren.Initialize()

renWin.Render()

#iren.Start()



#!/usr/bin/env python
from vtkmodules.vtkFiltersGeneral import vtkRotationFilter
from vtkmodules.vtkFiltersSources import vtkConeSource
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkDataSetMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

cone = vtkConeSource()
cone.SetRadius(0.05)
cone.SetHeight(0.25)
cone.SetResolution(256)
cone.SetCenter(0.15,0.0,0.15)
rotate = vtkRotationFilter()
rotate.SetInputConnection(cone.GetOutputPort())
rotate.SetAxisToZ()
rotate.SetCenter(0.0,0.0,0.0)
rotate.SetAngle(45)
rotate.SetNumberOfCopies(7)
rotate.CopyInputOn()
mapper = vtkDataSetMapper()
mapper.SetInputConnection(rotate.GetOutputPort())
actor = vtkActor()
actor.SetMapper(mapper)
ren1 = vtkRenderer()
ren1.AddActor(actor)
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
renWin.SetSize(512,512)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)
iren.Initialize()
renWin.Render()
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkCommonCore import vtkPoints
from vtkmodules.vtkCommonDataModel import (
    vtkCellArray,
    vtkPolyData,
)
from vtkmodules.vtkFiltersCore import (
    vtkCellCenters,
    vtkGenerateIds,
)
from vtkmodules.vtkFiltersSources import vtkSphereSource
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkActor2D,
    vtkPolyDataMapper,
    vtkPolyDataMapper2D,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
    vtkSelectVisiblePoints,
)
from vtkmodules.vtkRenderingLabel import vtkLabeledDataMapper
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# demonstrate use of point labeling and the selection window

# Create the RenderWindow, Renderer and both Actors
#
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

# Create a selection window
xmin = 200
xLength = 100
xmax = xmin + xLength
ymin = 200
yLength = 100
ymax = ymin + yLength

pts = vtkPoints()
pts.InsertPoint(0, xmin, ymin, 0)
pts.InsertPoint(1, xmax, ymin, 0)
pts.InsertPoint(2, xmax, ymax, 0)
pts.InsertPoint(3, xmin, ymax, 0)

rect = vtkCellArray()
rect.InsertNextCell(5)
rect.InsertCellPoint(0)
rect.InsertCellPoint(1)
rect.InsertCellPoint(2)
rect.InsertCellPoint(3)
rect.InsertCellPoint(0)

selectRect = vtkPolyData()
selectRect.SetPoints(pts)
selectRect.SetLines(rect)

rectMapper = vtkPolyDataMapper2D()
rectMapper.SetInputData(selectRect)

rectActor = vtkActor2D()
rectActor.SetMapper(rectMapper)

# Create asphere
sphere = vtkSphereSource()

sphereMapper = vtkPolyDataMapper()
sphereMapper.SetInputConnection(sphere.GetOutputPort())

sphereActor = vtkActor()
sphereActor.SetMapper(sphereMapper)

# Generate ids for labeling
ids = vtkGenerateIds()
ids.SetInputConnection(sphere.GetOutputPort())
ids.PointIdsOn()
ids.CellIdsOn()
ids.FieldDataOn()

# Create labels for points
visPts = vtkSelectVisiblePoints()
visPts.SetInputConnection(ids.GetOutputPort())
visPts.SetRenderer(ren1)
visPts.SelectionWindowOn()
visPts.SetSelection(xmin, xmin + xLength, ymin, ymin + yLength)

ldm = vtkLabeledDataMapper()
ldm.SetInputConnection(visPts.GetOutputPort())
#    ldm.SetLabelModeToLabelScalars()
#    ldm.SetLabelModeToLabelNormals()
ldm.SetLabelModeToLabelFieldData()
#    ldm.SetLabeledComponent(0)
ldm.SetFieldDataName("vtkPointIds")

pointLabels = vtkActor2D()
pointLabels.SetMapper(ldm)

# Create labels for cells
cc = vtkCellCenters()
cc.SetInputConnection(ids.GetOutputPort())

visCells = vtkSelectVisiblePoints()
visCells.SetInputConnection(cc.GetOutputPort())
visCells.SetRenderer(ren1)
visCells.SelectionWindowOn()
visCells.SetSelection(xmin, xmin + xLength, ymin, ymin + yLength)

cellMapper = vtkLabeledDataMapper()
cellMapper.SetInputConnection(visCells.GetOutputPort())
#    cellMapper.SetLabelModeToLabelScalars()
#    cellMapper.SetLabelModeToLabelNormals()
cellMapper.SetLabelModeToLabelFieldData()
cellMapper.SetFieldDataName("vtkCellIds")
cellMapper.GetLabelTextProperty().SetColor(0, 1, 0)

cellLabels = vtkActor2D()
cellLabels.SetMapper(cellMapper)

# Add the actors to the renderer, set the background and size
#
ren1.AddActor(sphereActor)
ren1.AddViewProp(rectActor)
ren1.AddViewProp(pointLabels)
ren1.AddViewProp(cellLabels)
ren1.SetBackground(1, 1, 1)

renWin.SetSize(500, 500)

renWin.Render()
# render the image
#

def PlaceWindow (xmin, ymin):
    global xLength, yLength
    xmax = xmin + xLength
    ymax = ymin + yLength
    visPts.SetSelection(xmin, xmax, ymin, ymax)
    visCells.SetSelection(xmin, xmax, ymin, ymax)
    pts.InsertPoint(0, xmin, ymin, 0)
    pts.InsertPoint(1, xmax, ymin, 0)
    pts.InsertPoint(2, xmax, ymax, 0)
    pts.InsertPoint(3, xmin, ymax, 0)
    pts.Modified()
    # because insertions don't modify object - performance reasons
    renWin.Render()

def MoveWindow ():
    y = 100
    while y < 300:
        x = 100
        while x < 300:
            PlaceWindow(x, y)
            x += 25
        y += 25


MoveWindow()
PlaceWindow(xmin, ymin)

#iren.Start()



#!/usr/bin/env python
from vtkmodules.vtkCommonTransforms import vtkTransform
from vtkmodules.vtkFiltersCore import (
    vtkAppendPolyData,
    vtkProbeFilter,
    vtkStructuredGridOutlineFilter,
    vtkTubeFilter,
)
from vtkmodules.vtkFiltersGeneral import vtkTransformPolyDataFilter
from vtkmodules.vtkFiltersSources import vtkLineSource
from vtkmodules.vtkIOParallel import vtkMultiBlockPLOT3DReader
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
from vtkmodules.vtkRenderingAnnotation import vtkXYPlotActor
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# create pipeline
#
pl3d = vtkMultiBlockPLOT3DReader()
pl3d.SetXYZFileName(VTK_DATA_ROOT + "/Data/combxyz.bin")
pl3d.SetQFileName(VTK_DATA_ROOT + "/Data/combq.bin")
pl3d.SetScalarFunctionNumber(100)
pl3d.SetVectorFunctionNumber(202)
pl3d.Update()
output = pl3d.GetOutput().GetBlock(0)
# create three line probes
line = vtkLineSource()
line.SetResolution(30)
transL1 = vtkTransform()
transL1.Translate(3.7,0.0,28.37)
transL1.Scale(5,5,5)
transL1.RotateY(90)
tf = vtkTransformPolyDataFilter()
tf.SetInputConnection(line.GetOutputPort())
tf.SetTransform(transL1)
probe = vtkProbeFilter()
probe.SetInputConnection(tf.GetOutputPort())
probe.SetSourceData(output)
probe.Update()
transL2 = vtkTransform()
transL2.Translate(9.2,0.0,31.20)
transL2.Scale(5,5,5)
transL2.RotateY(90)
tf2 = vtkTransformPolyDataFilter()
tf2.SetInputConnection(line.GetOutputPort())
tf2.SetTransform(transL2)
probe2 = vtkProbeFilter()
probe2.SetInputConnection(tf2.GetOutputPort())
probe2.SetSourceData(output)
probe2.Update()
transL3 = vtkTransform()
transL3.Translate(13.27,0.0,33.40)
transL3.Scale(4.5,4.5,4.5)
transL3.RotateY(90)
tf3 = vtkTransformPolyDataFilter()
tf3.SetInputConnection(line.GetOutputPort())
tf3.SetTransform(transL3)
probe3 = vtkProbeFilter()
probe3.SetInputConnection(tf3.GetOutputPort())
probe3.SetSourceData(output)
probe3.Update()
appendF = vtkAppendPolyData()
appendF.AddInputData(probe.GetPolyDataOutput())
appendF.AddInputData(probe2.GetPolyDataOutput())
appendF.AddInputData(probe3.GetPolyDataOutput())
tuber = vtkTubeFilter()
tuber.SetInputConnection(appendF.GetOutputPort())
tuber.SetRadius(0.1)
lineMapper = vtkPolyDataMapper()
lineMapper.SetInputConnection(tuber.GetOutputPort())
lineActor = vtkActor()
lineActor.SetMapper(lineMapper)
probe.Update()
probe3.Update()
# probe the line and plot it
xyplot = vtkXYPlotActor()
xyplot.AddDataSetInput(probe.GetOutput())
xyplot.AddDataSetInputConnection(probe2.GetOutputPort())
xyplot.AddDataSetInput(probe3.GetOutput())
xyplot.GetPositionCoordinate().SetValue(0.0,0.67,0)
xyplot.GetPosition2Coordinate().SetValue(1.0,0.33,0)
#relative to Position
xyplot.SetXValuesToArcLength()
xyplot.SetNumberOfXLabels(6)
xyplot.SetTitle("Pressure vs. Arc Length (Zoomed View)")
xyplot.SetXTitle("")
xyplot.SetYTitle("P")
xyplot.SetXRange(.1,.35)
xyplot.SetYRange(.2,.4)
xyplot.GetProperty().SetColor(0,0,0)
xyplot.GetProperty().SetLineWidth(2)
# Set text prop color (same color for backward compat with test)
# Assign same object to all text props
tprop = xyplot.GetTitleTextProperty()
tprop.SetColor(xyplot.GetProperty().GetColor())
xyplot.SetAxisTitleTextProperty(tprop)
xyplot.SetAxisLabelTextProperty(tprop)
xyplot.SetLabelFormat("{:<#6.2f}")
xyplot2 = vtkXYPlotActor()
xyplot2.AddDataSetInput(probe.GetOutput())
xyplot2.AddDataSetInputConnection(probe2.GetOutputPort())
xyplot2.AddDataSetInputConnection(probe3.GetOutputPort())
xyplot2.GetPositionCoordinate().SetValue(0.00,0.33,0)
xyplot2.GetPosition2Coordinate().SetValue(1.0,0.33,0)
#relative to Position
xyplot2.SetXValuesToNormalizedArcLength()
xyplot2.SetNumberOfXLabels(6)
xyplot2.SetTitle("Pressure vs. Normalized Arc Length")
xyplot2.SetXTitle("")
xyplot2.SetYTitle("P")
xyplot2.PlotPointsOn()
xyplot2.PlotLinesOff()
xyplot2.GetProperty().SetColor(1,0,0)
xyplot2.GetProperty().SetPointSize(2)
# Set text prop color (same color for backward compat with test)
# Assign same object to all text props
tprop = xyplot2.GetTitleTextProperty()
tprop.SetColor(xyplot2.GetProperty().GetColor())
xyplot2.SetAxisTitleTextProperty(tprop)
xyplot2.SetAxisLabelTextProperty(tprop)
xyplot2.SetLabelFormat(xyplot.GetLabelFormat())
xyplot3 = vtkXYPlotActor()
xyplot3.AddDataSetInputConnection(probe.GetOutputPort())
xyplot3.AddDataSetInputConnection(probe2.GetOutputPort())
xyplot3.AddDataSetInputConnection(probe3.GetOutputPort())
xyplot3.GetPositionCoordinate().SetValue(0.0,0.0,0)
xyplot3.GetPosition2Coordinate().SetValue(1.0,0.33,0)
#relative to Position
xyplot3.SetXValuesToIndex()
xyplot3.SetNumberOfXLabels(6)
xyplot3.SetTitle("Pressure vs. Point Id")
xyplot3.SetXTitle("Probe Length")
xyplot3.SetYTitle("P")
xyplot3.PlotPointsOn()
xyplot3.GetProperty().SetColor(0,0,1)
xyplot3.GetProperty().SetPointSize(3)
# Set text prop color (same color for backward compat with test)
# Assign same object to all text props
tprop = xyplot3.GetTitleTextProperty()
tprop.SetColor(xyplot3.GetProperty().GetColor())
xyplot3.SetAxisTitleTextProperty(tprop)
xyplot3.SetAxisLabelTextProperty(tprop)
xyplot3.SetLabelFormat(xyplot.GetLabelFormat())
# draw an outline
outline = vtkStructuredGridOutlineFilter()
outline.SetInputData(output)
outlineMapper = vtkPolyDataMapper()
outlineMapper.SetInputConnection(outline.GetOutputPort())
outlineActor = vtkActor()
outlineActor.SetMapper(outlineMapper)
outlineActor.GetProperty().SetColor(0,0,0)
# Create graphics stuff
#
ren1 = vtkRenderer()
ren2 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.SetMultiSamples(0)
renWin.AddRenderer(ren1)
renWin.AddRenderer(ren2)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)
ren1.SetBackground(0.6784,0.8471,0.9020)
ren1.SetViewport(0,0,.5,1)
ren1.AddActor(outlineActor)
ren1.AddActor(lineActor)
ren2.SetBackground(1,1,1)
ren2.SetViewport(0.5,0.0,1.0,1.0)
ren2.AddViewProp(xyplot)
ren2.AddViewProp(xyplot2)
ren2.AddViewProp(xyplot3)
renWin.SetSize(790,400)
cam1 = ren1.GetActiveCamera()
cam1.SetClippingRange(3.95297,100)
cam1.SetFocalPoint(8.88908,0.595038,29.3342)
cam1.SetPosition(-12.3332,31.7479,41.2387)
cam1.SetViewUp(0.060772,-0.319905,0.945498)
iren.Initialize()
# render the image
#
# prevent the tk window from showing up then start the event loop
# --- end of script --



#!/usr/bin/env python3
# encoding: utf-8
"""Use instead of `python3 -m http.server` when you need CORS"""

from http.server import HTTPServer, SimpleHTTPRequestHandler
from functools import partial
import argparse
import os
import sys

class CORSRequestHandler(SimpleHTTPRequestHandler):
    def end_headers(self):
        self.send_header('Access-Control-Allow-Origin', '*')
        self.send_header('Cross-Origin-Embedder-Policy', 'require-corp')
        self.send_header('Cross-Origin-Opener-Policy', 'same-origin')
        return super(CORSRequestHandler, self).end_headers()

def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('-d', '--directory', default=os.getcwd(),
                        help='serve this directory '
                             '(default: current directory)')
    parser.add_argument('port', default=8000, type=int, nargs='?',
                        help='bind to this port '
                             '(default: %(default)s)')
    args = parser.parse_args()
    with HTTPServer(('localhost', args.port), partial(CORSRequestHandler,directory=args.directory)) as httpd:
        host, port = httpd.socket.getsockname()[:2]
        url_host = f'[{host}]' if ':' in host else host
        print(
            f"Serving HTTP on {host} port {port} "
            f"(http://{url_host}:{port}/) ..."
        )
        try:
            httpd.serve_forever()
        except KeyboardInterrupt:
            print("\nKeyboard interrupt received, exiting.")
            sys.exit(0)
        except Exception as e:
            sys.exit(0)

if __name__ == "__main__":
    main()
